#!/usr/bin/env python3
# ------------------------------------------------
# This file is juju managed
# ------------------------------------------------

# Copyright (C) 2008, 2009, 2012  James Troup <james.troup@canonical.com>
# Copyright (C) 2009  LaMont Jones <lamont.jones@canonical.com>

###############################################################################
"""Check nagios-formatted output from cronjobs and provide nagios interface."""

from optparse import OptionParser

from nagios_plugin3 import (
    CriticalError,
    UnknownError,
    WarnError,
    check_file_freshness,
    try_check,
)


###############################################################################


def check_and_open(filename, time_limit):
    """Check file for recent update and open.  Raise exception if too old."""
    check_file_freshness(filename, time_limit)
    return open(filename)


###############################################################################


def check_file_contents(input_filename, time_limit):
    """Process file contents and raise appropriate nagios result."""
    input_file = check_and_open(input_filename, time_limit)
    for line in input_file.readlines():
        line = line.rstrip()
        if not line:
            continue
        if line.startswith("WARN"):
            raise WarnError(line)
        if line.startswith("UNKNOWN"):
            raise UnknownError(line)
        elif line.startswith("OK"):
            print(line)
        else:
            raise CriticalError(line)


###############################################################################


def main():
    """Define main subroutine."""
    parser = OptionParser()
    parser.add_option(
        "--time",
        dest="time_limit",
        help="freshness time limit [default=%default]",
        metavar="SECONDS",
        default=1200,
        type=int,
    )
    parser.add_option(
        "-f",
        "--filename",
        dest="input_file",
        help=("file containing the output of cron_ilorest.py [default=%default]"),
        metavar="FILE",
        nargs=1,
        # default="/var/lib/nagios/UNSETOUTPUTFILE.out",
        type=str,
    )

    (opts, args) = parser.parse_args()

    try_check(check_file_contents, opts.input_file, opts.time_limit)
    print("All OK")


if __name__ == "__main__":
    main()
