#!/usr/bin/env python3
# -*- coding: us-ascii -*-
"""Script to check mdadm status collected from cron."""

import argparse
import os
import sys

from nagios_plugin3 import CriticalError, UnknownError, WarnError, try_check

try:
    # shared lib will be under $NAGIOS_PLUGIN_DIR at runtime
    from hw_health_lib import HWCheckArgumentParser
except ImportError:
    # shared lib will be under $CHARM_SOURCE_DIR/files/common during unit tests
    common_libs_dir = os.path.abspath(
        os.path.join(os.path.dirname(__file__), "..", "common")
    )
    if common_libs_dir not in sys.path:
        sys.path.append(common_libs_dir)
    from hw_health_lib import HWCheckArgumentParser

INPUT_FILE = "/var/lib/nagios/mdadm.out"
ARGS = argparse.Namespace()


def parse_output():
    """Process the cron output and raise exceptions if there are alertable states."""
    if not os.path.exists(ARGS.input_file):
        raise UnknownError("UNKNOWN: file not found ({})".format(ARGS.input_file))

    with open(ARGS.input_file, "r") as fd:
        for line in fd.readlines():
            line = line.strip()
            if line.startswith("CRITICAL: "):
                raise CriticalError(line)
            elif line.startswith("WARNING: "):
                raise WarnError(line)
            else:
                print(line)


def parse_args(argv=None):
    """Process CLI arguments."""
    parser = HWCheckArgumentParser(prog="check_mdadm", def_input_file=INPUT_FILE)
    return parser.parse_args(args=argv, namespace=ARGS)


def main(argv):
    """Define main subroutine."""
    parse_args(argv)
    try_check(parse_output)


if __name__ == "__main__":
    main(sys.argv[1:])
