import os
import sys
import unittest
from argparse import Namespace
from pathlib import Path

sys.path.append("files/hplog")
import cron_hplog  # noqa: E402


class TestCronHPlog(unittest.TestCase):
    def setUp(self):
        # Skip the v flag, it serves a different purpose
        self.test_flags = {"t", "f", "p"}

    def _get_no_error_sample(self, flag):
        _filepath = os.path.join(
            os.getcwd(), "tests", "hw-health-samples", "hplog.{}.ewah.out".format(flag)
        )
        return Path(_filepath).read_text()

    def test_parse_garbage_headers(self):
        for flag in self.test_flags:
            with self.subTest():
                expected = (
                    "UNKNOWN Unrecognised header line in 'hplog -{}' "
                    "output".format(flag)
                )
                funcname = cron_hplog.FLAG_PROCESSOR[flag]
                actual = getattr(cron_hplog, funcname)("garbage")
                self.assertEqual(actual, expected)

    def test_parse_flags_no_errors(self):
        cron_hplog.ARGS = Namespace(single_psu=False)
        for flag in self.test_flags:
            with self.subTest():
                funcname = cron_hplog.FLAG_PROCESSOR[flag]
                sample = self._get_no_error_sample(flag)
                actual = getattr(cron_hplog, funcname)(sample)
                self.assertIsNone(actual)
