import os
import sys
import unittest
import unittest.mock as mock
from pathlib import Path

sys.path.append("files/ilorest")
from cron_ilorest import CronILOrest  # noqa: E402


UNIT_TEST_PATH = os.path.dirname(os.path.abspath(__file__))
SAMPLE_PATH = os.path.join(UNIT_TEST_PATH, "../hw-health-samples")


class TestCronILOrest(unittest.TestCase):
    def ilorest_side_effects(self, *args, selector, errors=False, **kwargs):
        """Return sample command output for mock."""
        if errors:
            filename = "ilorest.list.bad.{}".format(selector)
        else:
            filename = "ilorest.list.{}".format(selector)
        _filepath = os.path.join(SAMPLE_PATH, filename)
        return Path(_filepath).read_text()

    @mock.patch.object(CronILOrest, "_get_json_ilorest_output")
    def test_check_default_selectors_no_errors(self, mock_output):
        cronilorest = CronILOrest()
        for selector in cronilorest.args.selectors:
            mock_output.return_value = self.ilorest_side_effects(selector=selector)
            errors = cronilorest.check_selector(selector)
            assert errors == []

    @mock.patch.object(CronILOrest, "_get_json_ilorest_output")
    def test_check_default_selectors_has_errors(self, mock_output):
        cronilorest = CronILOrest()
        for selector in cronilorest.args.selectors:
            mock_output.return_value = self.ilorest_side_effects(
                selector=selector, errors=True
            )
            errors = cronilorest.check_selector(selector)
            assert errors != []
