import os
import sys
import unittest
from pathlib import Path

sys.path.append("files/ssacli")
import cron_ssacli  # noqa: E402


class TestCronSsacli(unittest.TestCase):
    def test_parse_controller_output_failedbattery(self):
        _filepath = os.path.join(
            os.getcwd(),
            "tests",
            "hw-health-samples",
            "ssacli.ctrl.status.failedbattery.out",
        )
        output = Path(_filepath).read_text()
        actual = cron_ssacli._parse_controller_output(output)
        expected = (
            "Cache Status on Smart Array P410i in Slot 0 (Embedded) "
            "is 'TEMPORARILY DISABLED'"
        )
        self.assertEqual(actual, expected)

    def test_parse_degraded_array_output(self):
        _filepath = os.path.join(
            os.getcwd(),
            "tests",
            "hw-health-samples",
            "ssacli.array.status.faileddrive.out",
        )
        output = Path(_filepath).read_text()
        actual = cron_ssacli._parse_array_output(output)
        expected = 'logicaldrive 1 is "INTERIM RECOVERY MODE"'
        self.assertEqual(actual, expected)

    def test_parse_ok_array_output(self):
        _filepath = os.path.join(
            os.getcwd(), "tests", "hw-health-samples", "ssacli.array.status.ok.out"
        )
        output = Path(_filepath).read_text()
        actual = cron_ssacli._parse_array_output(output)
        self.assertIsNone(actual)
