import sys
import unittest
import unittest.mock as mock

import hwhealth.tools as tools  # noqa: E402

sys.path.append("lib")


class TestIpmiSensor(unittest.TestCase):
    def test_create_exclusion(self):
        config_items = ['["~.*Link Down|Slot/Connector"]', "--extra-args"]
        with mock.patch("hwhealth.tools.Tool.__init__") as mock_tool_init:
            with mock.patch("hwhealth.tools.hookenv.config", side_effect=config_items):
                with mock.patch("hwhealth.tools.write_file") as mock_write:
                    tools.Ipmi()
        mock_tool_init.assert_called_with(
            cron_script="cron_ipmi_sensors.py",
            cron_script_args="--extra-args --sexclude /var/lib/nagios/ipmi_exclude",
        )
        mock_write.assert_called_with(
            "/var/lib/nagios/ipmi_exclude",
            "~.*Link Down|Slot/Connector",
            owner="root",
            group="root",
            perms=0o444,
        )

    @mock.patch("hwhealth.tools.hookenv.charm_dir", side_effect=lambda: "the-charm-dir")
    @mock.patch(
        "hwhealth.tools.nrpe.get_nagios_hostname", side_effect=lambda: "the-hostname"
    )
    @mock.patch("hwhealth.tools.write_file")
    @mock.patch("hwhealth.tools.hookenv.config")
    def test_add_date_range_to_cron_args(self, config, *rest_of_mocks):
        subtests = [  # (ipmi_check_options, expected _cron_script_args)
            (
                "--option1 --option2 arg1",
                "--option1 --option2 arg1 --sexclude {} "
                "--seloptions --date-range=03/08/2021-now".format(
                    tools.Ipmi.EXCLUDE_FILE
                ),
            ),
            (
                "--option1 --option2 arg1 --seloptions --some-option",
                "--option1 --option2 arg1 --seloptions "
                "--some-option,--date-range=03/08/2021-now --sexclude {}".format(
                    tools.Ipmi.EXCLUDE_FILE
                ),
            ),
            (
                "--option1 --option2 arg1 --seloptions --some-option --option3",
                "--option1 --option2 arg1 --seloptions "
                "--some-option,--date-range=03/08/2021-now --option3 "
                "--sexclude {}".format(tools.Ipmi.EXCLUDE_FILE),
            ),
            (
                "--seloptions --some-option --option1 --option2 arg1",
                "--seloptions --some-option,--date-range=03/08/2021-now "
                "--option1 --option2 arg1 --sexclude {}".format(
                    tools.Ipmi.EXCLUDE_FILE
                ),
            ),
            # Pre-existing date range options are overriden
            (
                "--seloptions --some-option,--date-range=09/01/2021 "
                "--option1 --option2 arg1",
                "--seloptions --some-option,--date-range=03/08/2021-now "
                "--option1 --option2 arg1 --sexclude {}".format(
                    tools.Ipmi.EXCLUDE_FILE
                ),
            ),
            (
                "--seloptions --date-range=09/01/2021,--some-option "
                "--option1 --option2 arg1",
                "--seloptions --some-option,--date-range=03/08/2021-now "
                "--option1 --option2 arg1 --sexclude {}".format(
                    tools.Ipmi.EXCLUDE_FILE
                ),
            ),
            (
                "--seloptions --some-option,--date-range=09/01/2021,"
                "--some-option2 --option1 --option2 arg1",
                "--seloptions "
                "--some-option,--some-option2,--date-range=03/08/2021-now "
                "--option1 --option2 arg1 --sexclude {}".format(
                    tools.Ipmi.EXCLUDE_FILE
                ),
            ),
            (
                "--seloptions --date-range=09/01/2021 --option1 --option2 arg1",
                "--seloptions --date-range=03/08/2021-now --option1 "
                "--option2 arg1 --sexclude {}".format(tools.Ipmi.EXCLUDE_FILE),
            ),
        ]
        for i in subtests:
            config_dict = {
                "ipmi_check_exclusions": "[]",  # Has to be a valid YAML doc.
                "ipmi_check_options": i[0],
            }
            config.side_effect = lambda x: config_dict[x]

            ipmi = tools.Ipmi()
            ipmi.add_date_range_to_cron_args("03/08/2021")
            self.assertEqual(ipmi._cron_script_args, i[1])
