import os
import sys
import unittest
import unittest.mock as mock
from glob import glob

sys.path.append("lib")
from hwhealth.discovery.lshw import Hardware  # noqa E401

sys.path.append("tests")
from expected.lshw import EXPECTED  # noqa E401


class BaseTest(unittest.TestCase):
    # override these in the subclass
    platform = None
    distro = None
    test_pattern = None

    def setUp(self):
        self.samples = glob(os.path.join(os.getcwd(), self.test_pattern))
        self.platform_patcher = mock.patch("hwhealth.discovery.lshw.get_platform")
        self.distrib_patcher = mock.patch(
            "hwhealth.discovery.lshw.get_distrib_codename"
        )
        self.platform_patcher.start().return_value = self.platform
        self.distrib_patcher.start().return_value = self.distro

    def tearDown(self):
        self.distrib_patcher.stop()


class BaseTestMixin:
    def test_get_system(self):
        for filename in self.samples:
            basename = os.path.basename(filename)
            with self.subTest(msg="Subtest {}".format(basename)):
                actual = Hardware(filename=filename).get_system
                expected = EXPECTED.get(basename).get("system")
                self.assertEqual(actual, expected)

    def test_get_motherboard(self):
        for filename in self.samples:
            basename = os.path.basename(filename)
            with self.subTest(msg="Subtest {}".format(basename)):
                actual = Hardware(filename=filename).get_motherboard
                basename = os.path.basename(filename)
                expected = EXPECTED.get(basename).get("motherboard")
                self.assertEqual(actual, expected)

    def test_get_storage_class_info(self):
        for filename in self.samples:
            basename = os.path.basename(filename)
            with self.subTest(msg="Subtest {}".format(basename)):
                actual = Hardware(filename=filename).get_storage_class_info
                basename = os.path.basename(filename)
                expected = EXPECTED.get(basename).get("storage_class_info")
                self.assertEqual(actual, expected)

    def test_get_disk_class_info(self):
        for filename in self.samples:
            basename = os.path.basename(filename)
            with self.subTest(msg="Subtest {}".format(basename)):
                actual = Hardware(filename=filename).get_disk_class_info
                basename = os.path.basename(filename)
                expected = EXPECTED.get(basename).get("disk_class_info")
                self.assertEqual(actual, expected)

    def test_get_network_class_info(self):
        for filename in self.samples:
            basename = os.path.basename(filename)
            with self.subTest(msg="Subtest {}".format(basename)):
                actual = Hardware(filename=filename).get_network_class_info
                basename = os.path.basename(filename)
                expected = EXPECTED.get(basename).get("network_class_info")
                self.assertEqual(actual, expected)


class TestHardwareBionic(BaseTest, BaseTestMixin):
    platform = "ubuntu"
    distro = "bionic"
    test_pattern = "tests/hw-health-samples/lshw.*.json"


class TestHardwareFocal(BaseTest, BaseTestMixin):
    platform = "ubuntu"
    distro = "focal"
    test_pattern = "tests/hw-health-samples/lshw-focal.*.json"
